@@ -17,7 +17,11 @@
 
 package org.apache.eventmesh.common.protocol;
 
-public class SubscriptionItem {
+import java.io.Serializable;
+
+import com.google.common.base.Objects;
+
+public class SubscriptionItem implements Serializable {
 
     private String topic;
 
@@ -60,11 +64,28 @@ public class SubscriptionItem {
 
     @Override
     public String toString() {
-        return "SubscriptionItem{" +
-                "topic=" + topic +
-                ", mode=" + mode +
-                ", type=" + type +
-                '}';
+        return "SubscriptionItem{"
+                + "topic=" + topic
+                + ", mode=" + mode
+                + ", type=" + type
+                + '}';
+    }
+
+    @Override
+    public boolean equals(Object o) {
+        if (this == o) {
+            return true;
+        }
+        if (o == null || getClass() != o.getClass()) {
+            return false;
+        }
+        SubscriptionItem that = (SubscriptionItem) o;
+        return Objects.equal(topic, that.topic) && mode == that.mode && type == that.type;
+    }
+
+    @Override
+    public int hashCode() {
+        return Objects.hashCode(topic, mode, type);
     }
 }
 
