@@ -31,7 +31,6 @@ import org.apache.eventmesh.runtime.core.protocol.http.async.AsyncContext;
 import org.apache.eventmesh.runtime.core.protocol.http.processor.inf.HttpRequestProcessor;
 import org.apache.eventmesh.runtime.metrics.http.HTTPMetricsServer;
 import org.apache.eventmesh.runtime.trace.AttributeKeys;
-import org.apache.eventmesh.runtime.trace.OpenTelemetryTraceFactory;
 import org.apache.eventmesh.runtime.trace.SpanKey;
 import org.apache.eventmesh.runtime.util.RemotingHelper;
 
@@ -53,8 +52,6 @@ import javax.net.ssl.SSLEngine;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import com.google.common.base.Preconditions;
-
 import io.netty.bootstrap.ServerBootstrap;
 import io.netty.channel.ChannelDuplexHandler;
 import io.netty.channel.ChannelFuture;
@@ -97,6 +94,8 @@ import io.opentelemetry.context.propagation.TextMapGetter;
 import io.opentelemetry.context.propagation.TextMapPropagator;
 import io.opentelemetry.semconv.trace.attributes.SemanticAttributes;
 
+import com.google.common.base.Preconditions;
+
 public abstract class AbstractHTTPServer extends AbstractRemotingServer {
 
     public Logger httpServerLogger = LoggerFactory.getLogger(this.getClass());
@@ -111,23 +110,21 @@ public abstract class AbstractHTTPServer extends AbstractRemotingServer {
 
     private boolean useTLS;
 
-    private Boolean useTrace = true; //Determine whether trace is enabled
+    public Boolean useTrace = false; //Determine whether trace is enabled
 
     public TextMapPropagator textMapPropagator;
 
-    public OpenTelemetryTraceFactory openTelemetryTraceFactory;
-
     public Tracer tracer;
 
     public ThreadPoolExecutor asyncContextCompleteHandler =
-        ThreadPoolFactory.createThreadPoolExecutor(10, 10, "EventMesh-http-asyncContext-");
+            ThreadPoolFactory.createThreadPoolExecutor(10, 10, "EventMesh-http-asyncContext-");
 
     static {
         DiskAttribute.deleteOnExitTemporaryFile = false;
     }
 
     protected final Map<String/* request code */, Pair<HttpRequestProcessor, ThreadPoolExecutor>>
-        processorTable = new HashMap<>(64);
+            processorTable = new HashMap<>(64);
 
     public AbstractHTTPServer(int port, boolean useTLS) {
         this.port = port;
@@ -138,7 +135,7 @@ public abstract class AbstractHTTPServer extends AbstractRemotingServer {
         FullHttpResponse response = new DefaultFullHttpResponse(HttpVersion.HTTP_1_1, status);
         HttpHeaders responseHeaders = response.headers();
         responseHeaders.add(
-            HttpHeaderNames.CONTENT_TYPE, String.format("text/plain; charset=%s", EventMeshConstants.DEFAULT_CHARSET)
+                HttpHeaderNames.CONTENT_TYPE, String.format("text/plain; charset=%s", EventMeshConstants.DEFAULT_CHARSET)
         );
         responseHeaders.add(HttpHeaderNames.CONTENT_LENGTH, response.content().readableBytes());
         responseHeaders.add(HttpHeaderNames.CONNECTION, HttpHeaderValues.KEEP_ALIVE);
@@ -162,14 +159,11 @@ public abstract class AbstractHTTPServer extends AbstractRemotingServer {
             }
         }
 
-        ctx.writeAndFlush(response).addListener(new ChannelFutureListener() {
-            @Override
-            public void operationComplete(ChannelFuture f) {
-                if (!f.isSuccess()) {
-                    httpLogger.warn("send response to [{}] fail, will close this channel",
-                        RemotingHelper.parseChannelRemoteAddr(f.channel()));
-                    f.channel().close();
-                }
+        ctx.writeAndFlush(response).addListener((ChannelFutureListener) f -> {
+            if (!f.isSuccess()) {
+                httpLogger.warn("send response to [{}] fail, will close this channel",
+                    RemotingHelper.parseChannelRemoteAddr(f.channel()));
+                f.channel().close();
             }
         });
     }
@@ -181,9 +175,9 @@ public abstract class AbstractHTTPServer extends AbstractRemotingServer {
             ServerBootstrap b = new ServerBootstrap();
             SSLContext sslContext = useTLS ? SSLContextFactory.getSslContext() : null;
             b.group(this.bossGroup, this.workerGroup)
-                .channel(NioServerSocketChannel.class)
-                .childHandler(new HttpsServerInitializer(sslContext))
-                .childOption(ChannelOption.SO_KEEPALIVE, Boolean.TRUE);
+                    .channel(NioServerSocketChannel.class)
+                    .childHandler(new HttpsServerInitializer(sslContext))
+                    .childOption(ChannelOption.SO_KEEPALIVE, Boolean.TRUE);
             try {
                 httpServerLogger.info("HTTPServer[port={}] started......", this.port);
                 ChannelFuture future = b.bind(this.port).sync();
@@ -195,7 +189,6 @@ public abstract class AbstractHTTPServer extends AbstractRemotingServer {
                 } catch (Exception e1) {
                     httpServerLogger.error("HTTPServer shutdown Err!", e);
                 }
-                return;
             }
         };
 
@@ -227,8 +220,8 @@ public abstract class AbstractHTTPServer extends AbstractRemotingServer {
         Map<String, Object> headerParam = new HashMap<>();
         for (String key : fullReq.headers().names()) {
             if (StringUtils.equalsIgnoreCase(HttpHeaderNames.CONTENT_TYPE.toString(), key)
-                || StringUtils.equalsIgnoreCase(HttpHeaderNames.ACCEPT_ENCODING.toString(), key)
-                || StringUtils.equalsIgnoreCase(HttpHeaderNames.CONTENT_LENGTH.toString(), key)) {
+                    || StringUtils.equalsIgnoreCase(HttpHeaderNames.ACCEPT_ENCODING.toString(), key)
+                    || StringUtils.equalsIgnoreCase(HttpHeaderNames.CONTENT_LENGTH.toString(), key)) {
                 continue;
             }
             headerParam.put(key, fullReq.headers().get(key));
@@ -268,7 +261,7 @@ public abstract class AbstractHTTPServer extends AbstractRemotingServer {
     private void preProcessHttpRequestHeader(ChannelHandlerContext ctx, HttpRequest httpRequest) {
         HttpHeaders requestHeaders = httpRequest.headers();
         requestHeaders.set(ProtocolKey.ClientInstanceKey.IP,
-            RemotingHelper.parseChannelRemoteAddr(ctx.channel()));
+                RemotingHelper.parseChannelRemoteAddr(ctx.channel()));
 
         String protocolVersion = httpRequest.headers().get(ProtocolKey.VERSION);
         if (StringUtils.isBlank(protocolVersion)) {
@@ -291,7 +284,7 @@ public abstract class AbstractHTTPServer extends AbstractRemotingServer {
             getDecoder.parameters().forEach((key, value) -> httpRequestBody.put(key, value.get(0)));
         } else if (HttpMethod.POST.equals(httpRequest.method())) {
             HttpPostRequestDecoder decoder =
-                new HttpPostRequestDecoder(defaultHttpDataFactory, httpRequest);
+                    new HttpPostRequestDecoder(defaultHttpDataFactory, httpRequest);
             for (InterfaceHttpData parm : decoder.getBodyHttpDatas()) {
                 if (parm.getHttpDataType() == InterfaceHttpData.HttpDataType.Attribute) {
                     Attribute data = (Attribute) parm;
@@ -300,7 +293,7 @@ public abstract class AbstractHTTPServer extends AbstractRemotingServer {
             }
             decoder.destroy();
         }
-        metrics.summaryMetrics.recordDecodeTimeCost(System.currentTimeMillis() - bodyDecodeStart);
+        metrics.getSummaryMetrics().recordDecodeTimeCost(System.currentTimeMillis() - bodyDecodeStart);
         return httpRequestBody;
     }
 
@@ -324,9 +317,9 @@ public abstract class AbstractHTTPServer extends AbstractRemotingServer {
                     }
                 });
                 span = tracer.spanBuilder("HTTP " + httpRequest.method())
-                    .setParent(context)
-                    .setSpanKind(SpanKind.SERVER)
-                    .startSpan();
+                        .setParent(context)
+                        .setSpanKind(SpanKind.SERVER)
+                        .startSpan();
                 //attach the span to the server context
                 context = context.with(SpanKey.SERVER_KEY, span);
                 //put the context in channel
@@ -340,16 +333,16 @@ public abstract class AbstractHTTPServer extends AbstractRemotingServer {
                     sendError(ctx, errorStatus);
                     return;
                 }
-                metrics.summaryMetrics.recordHTTPRequest();
+                metrics.getSummaryMetrics().recordHTTPRequest();
 
                 final HttpCommand requestCommand = new HttpCommand();
 
                 final Map<String, Object> bodyMap = parseHttpRequestBody(httpRequest);
 
                 String requestCode =
-                    (httpRequest.method() == HttpMethod.POST)
-                        ? httpRequest.headers().get(ProtocolKey.REQUEST_CODE)
-                        : MapUtils.getString(bodyMap, StringUtils.lowerCase(ProtocolKey.REQUEST_CODE), "");
+                        (httpRequest.method() == HttpMethod.POST)
+                                ? httpRequest.headers().get(ProtocolKey.REQUEST_CODE)
+                                : MapUtils.getString(bodyMap, StringUtils.lowerCase(ProtocolKey.REQUEST_CODE), "");
 
                 requestCommand.setHttpMethod(httpRequest.method().name());
                 requestCommand.setHttpVersion(httpRequest.protocolVersion().protocolName());
@@ -364,10 +357,10 @@ public abstract class AbstractHTTPServer extends AbstractRemotingServer {
                 HttpCommand responseCommand = null;
 
                 if (StringUtils.isBlank(requestCode)
-                    || !processorTable.containsKey(requestCode)
-                    || !RequestCode.contains(Integer.valueOf(requestCode))) {
+                        || !processorTable.containsKey(requestCode)
+                        || !RequestCode.contains(Integer.valueOf(requestCode))) {
                     responseCommand =
-                        requestCommand.createHttpCommandResponse(EventMeshRetCode.EVENTMESH_REQUESTCODE_INVALID);
+                            requestCommand.createHttpCommandResponse(EventMeshRetCode.EVENTMESH_REQUESTCODE_INVALID);
                     sendResponse(ctx, responseCommand.httpResponse());
                     return;
                 }
@@ -386,7 +379,7 @@ public abstract class AbstractHTTPServer extends AbstractRemotingServer {
                 }
 
                 AsyncContext<HttpCommand> asyncContext =
-                    new AsyncContext<>(requestCommand, responseCommand, asyncContextCompleteHandler);
+                        new AsyncContext<>(requestCommand, responseCommand, asyncContextCompleteHandler);
                 processEventMeshRequest(ctx, asyncContext);
             } catch (Exception ex) {
                 httpServerLogger.error("AbrstractHTTPServer.HTTPHandler.channelRead0 err", ex);
@@ -410,7 +403,7 @@ public abstract class AbstractHTTPServer extends AbstractRemotingServer {
                         HttpRequestProcessor processor = choosed.getObject1();
                         if (processor.rejectRequest()) {
                             HttpCommand responseCommand =
-                                request.createHttpCommandResponse(EventMeshRetCode.EVENTMESH_REJECT_BY_PROCESSOR_ERROR);
+                                    request.createHttpCommandResponse(EventMeshRetCode.EVENTMESH_REJECT_BY_PROCESSOR_ERROR);
                             asyncContext.onComplete(responseCommand);
                             if (asyncContext.isComplete()) {
                                 if (httpLogger.isDebugEnabled()) {
@@ -426,8 +419,8 @@ public abstract class AbstractHTTPServer extends AbstractRemotingServer {
                             return;
                         }
 
-                        metrics.summaryMetrics
-                            .recordHTTPReqResTimeCost(System.currentTimeMillis() - request.getReqTime());
+                        metrics.getSummaryMetrics()
+                                .recordHTTPReqResTimeCost(System.currentTimeMillis() - request.getReqTime());
 
                         if (httpLogger.isDebugEnabled()) {
                             httpLogger.debug("{}", asyncContext.getResponse());
@@ -441,8 +434,8 @@ public abstract class AbstractHTTPServer extends AbstractRemotingServer {
             } catch (RejectedExecutionException re) {
                 HttpCommand responseCommand = request.createHttpCommandResponse(EventMeshRetCode.OVERLOAD);
                 asyncContext.onComplete(responseCommand);
-                metrics.summaryMetrics.recordHTTPDiscard();
-                metrics.summaryMetrics.recordHTTPReqResTimeCost(System.currentTimeMillis() - request.getReqTime());
+                metrics.getSummaryMetrics().recordHTTPDiscard();
+                metrics.getSummaryMetrics().recordHTTPReqResTimeCost(System.currentTimeMillis() - request.getReqTime());
                 try {
                     sendResponse(ctx, asyncContext.getResponse().httpResponse());
                 } catch (Exception e) {
@@ -487,8 +480,8 @@ public abstract class AbstractHTTPServer extends AbstractRemotingServer {
             int c = connections.incrementAndGet();
             if (c > 20000) {
                 httpServerLogger
-                    .warn("client|http|channelActive|remoteAddress={}|msg={}", remoteAddress,
-                        "too many client(20000) connect this eventMesh server");
+                        .warn("client|http|channelActive|remoteAddress={}|msg={}", remoteAddress,
+                                "too many client(20000) connect this eventMesh server");
                 ctx.close();
                 return;
             }
@@ -509,7 +502,7 @@ public abstract class AbstractHTTPServer extends AbstractRemotingServer {
                 if (event.state().equals(IdleState.ALL_IDLE)) {
                     final String remoteAddress = RemotingHelper.parseChannelRemoteAddr(ctx.channel());
                     httpServerLogger.info("client|http|userEventTriggered|remoteAddress={}|msg={}",
-                        remoteAddress, evt.getClass().getName());
+                            remoteAddress, evt.getClass().getName());
                     ctx.close();
                 }
             }
@@ -537,10 +530,10 @@ public abstract class AbstractHTTPServer extends AbstractRemotingServer {
                 pipeline.addFirst("ssl", new SslHandler(sslEngine));
             }
             pipeline.addLast(new HttpRequestDecoder(),
-                new HttpResponseEncoder(),
-                new HttpConnectionHandler(),
-                new HttpObjectAggregator(Integer.MAX_VALUE),
-                new HTTPHandler());
+                    new HttpResponseEncoder(),
+                    new HttpConnectionHandler(),
+                    new HttpObjectAggregator(Integer.MAX_VALUE),
+                    new HTTPHandler());
         }
     }
 
