@@ -17,11 +17,7 @@
 
 package org.apache.eventmesh.runtime.core.protocol.http.processor;
 
-import io.cloudevents.CloudEvent;
-import io.cloudevents.core.builder.CloudEventBuilder;
-
 import org.apache.eventmesh.api.RequestReplyCallback;
-import org.apache.eventmesh.common.utils.IPUtils;
 import org.apache.eventmesh.common.protocol.ProtocolTransportObject;
 import org.apache.eventmesh.common.protocol.http.HttpCommand;
 import org.apache.eventmesh.common.protocol.http.body.message.SendMessageRequestBody;
@@ -30,6 +26,7 @@ import org.apache.eventmesh.common.protocol.http.common.EventMeshRetCode;
 import org.apache.eventmesh.common.protocol.http.common.ProtocolKey;
 import org.apache.eventmesh.common.protocol.http.common.RequestCode;
 import org.apache.eventmesh.common.protocol.http.header.message.SendMessageResponseHeader;
+import org.apache.eventmesh.common.utils.IPUtils;
 import org.apache.eventmesh.common.utils.JsonUtils;
 import org.apache.eventmesh.protocol.api.ProtocolAdaptor;
 import org.apache.eventmesh.protocol.api.ProtocolPluginFactory;
@@ -46,12 +43,15 @@ import org.apache.eventmesh.runtime.util.RemotingHelper;
 
 import org.apache.commons.lang3.StringUtils;
 
+import java.nio.charset.StandardCharsets;
 import java.util.Objects;
 import java.util.concurrent.TimeUnit;
 
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import io.cloudevents.CloudEvent;
+import io.cloudevents.core.builder.CloudEventBuilder;
 import io.netty.channel.ChannelHandlerContext;
 
 public class SendSyncMessageProcessor implements HttpRequestProcessor {
@@ -72,25 +72,25 @@ public class SendSyncMessageProcessor implements HttpRequestProcessor {
 
     @Override
     public void processRequest(ChannelHandlerContext ctx, AsyncContext<HttpCommand> asyncContext)
-        throws Exception {
+            throws Exception {
 
         HttpCommand responseEventMeshCommand;
 
         cmdLogger.info("cmd={}|{}|client2eventMesh|from={}|to={}",
-            RequestCode.get(Integer.valueOf(asyncContext.getRequest().getRequestCode())),
-            EventMeshConstants.PROTOCOL_HTTP,
-            RemotingHelper.parseChannelRemoteAddr(ctx.channel()), IPUtils.getLocalAddress());
+                RequestCode.get(Integer.valueOf(asyncContext.getRequest().getRequestCode())),
+                EventMeshConstants.PROTOCOL_HTTP,
+                RemotingHelper.parseChannelRemoteAddr(ctx.channel()), IPUtils.getLocalAddress());
 
         ProtocolAdaptor<ProtocolTransportObject> httpCommandProtocolAdaptor = ProtocolPluginFactory.getProtocolAdaptor("cloudevents");
         CloudEvent event = httpCommandProtocolAdaptor.toCloudEvent(asyncContext.getRequest());
 
         SendMessageResponseHeader sendMessageResponseHeader =
-            SendMessageResponseHeader
-                .buildHeader(Integer.valueOf(asyncContext.getRequest().getRequestCode()),
-                    eventMeshHTTPServer.getEventMeshHttpConfiguration().eventMeshCluster,
-                    IPUtils.getLocalAddress(),
-                    eventMeshHTTPServer.getEventMeshHttpConfiguration().eventMeshEnv,
-                    eventMeshHTTPServer.getEventMeshHttpConfiguration().eventMeshIDC);
+                SendMessageResponseHeader
+                        .buildHeader(Integer.valueOf(asyncContext.getRequest().getRequestCode()),
+                                eventMeshHTTPServer.getEventMeshHttpConfiguration().eventMeshCluster,
+                                IPUtils.getLocalAddress(),
+                                eventMeshHTTPServer.getEventMeshHttpConfiguration().eventMeshEnv,
+                                eventMeshHTTPServer.getEventMeshHttpConfiguration().eventMeshIDC);
 
         //validate event
         if (event == null
@@ -100,58 +100,58 @@ public class SendSyncMessageProcessor implements HttpRequestProcessor {
                 || StringUtils.isBlank(event.getType())
                 || StringUtils.isBlank(event.getSubject())) {
             responseEventMeshCommand = asyncContext.getRequest().createHttpCommandResponse(
-                sendMessageResponseHeader,
-                SendMessageResponseBody
-                    .buildBody(EventMeshRetCode.EVENTMESH_PROTOCOL_HEADER_ERR.getRetCode(),
-                        EventMeshRetCode.EVENTMESH_PROTOCOL_HEADER_ERR.getErrMsg()));
+                    sendMessageResponseHeader,
+                    SendMessageResponseBody
+                            .buildBody(EventMeshRetCode.EVENTMESH_PROTOCOL_HEADER_ERR.getRetCode(),
+                                    EventMeshRetCode.EVENTMESH_PROTOCOL_HEADER_ERR.getErrMsg()));
             asyncContext.onComplete(responseEventMeshCommand);
             return;
         }
 
         String idc = Objects.requireNonNull(event.getExtension(ProtocolKey.ClientInstanceKey.IDC))
-            .toString();
+                .toString();
         String pid = Objects.requireNonNull(event.getExtension(ProtocolKey.ClientInstanceKey.PID))
-            .toString();
+                .toString();
         String sys = Objects.requireNonNull(event.getExtension(ProtocolKey.ClientInstanceKey.SYS))
-            .toString();
+                .toString();
 
         //validate event-extension
         if (StringUtils.isBlank(idc)
-            || StringUtils.isBlank(pid)
-            || !StringUtils.isNumeric(pid)
-            || StringUtils.isBlank(sys)) {
+                || StringUtils.isBlank(pid)
+                || !StringUtils.isNumeric(pid)
+                || StringUtils.isBlank(sys)) {
             responseEventMeshCommand = asyncContext.getRequest().createHttpCommandResponse(
-                sendMessageResponseHeader,
-                SendMessageResponseBody
-                    .buildBody(EventMeshRetCode.EVENTMESH_PROTOCOL_HEADER_ERR.getRetCode(),
-                        EventMeshRetCode.EVENTMESH_PROTOCOL_HEADER_ERR.getErrMsg()));
+                    sendMessageResponseHeader,
+                    SendMessageResponseBody
+                            .buildBody(EventMeshRetCode.EVENTMESH_PROTOCOL_HEADER_ERR.getRetCode(),
+                                    EventMeshRetCode.EVENTMESH_PROTOCOL_HEADER_ERR.getErrMsg()));
             asyncContext.onComplete(responseEventMeshCommand);
             return;
         }
 
         String bizNo =
-            Objects.requireNonNull(event.getExtension(SendMessageRequestBody.BIZSEQNO)).toString();
+                Objects.requireNonNull(event.getExtension(SendMessageRequestBody.BIZSEQNO)).toString();
         String uniqueId =
-            Objects.requireNonNull(event.getExtension(SendMessageRequestBody.UNIQUEID)).toString();
+                Objects.requireNonNull(event.getExtension(SendMessageRequestBody.UNIQUEID)).toString();
         String producerGroup =
-            Objects.requireNonNull(event.getExtension(SendMessageRequestBody.PRODUCERGROUP))
-                .toString();
+                Objects.requireNonNull(event.getExtension(SendMessageRequestBody.PRODUCERGROUP))
+                        .toString();
         String topic = event.getSubject();
         String ttl =
-            Objects.requireNonNull(event.getExtension(SendMessageRequestBody.TTL)).toString();
+                Objects.requireNonNull(event.getExtension(SendMessageRequestBody.TTL)).toString();
 
         //validate body
         if (StringUtils.isBlank(bizNo)
-            || StringUtils.isBlank(uniqueId)
-            || StringUtils.isBlank(producerGroup)
-            || StringUtils.isBlank(topic)
-            || event.getData() == null
-            || StringUtils.isBlank(ttl)) {
+                || StringUtils.isBlank(uniqueId)
+                || StringUtils.isBlank(producerGroup)
+                || StringUtils.isBlank(topic)
+                || event.getData() == null
+                || StringUtils.isBlank(ttl)) {
             responseEventMeshCommand = asyncContext.getRequest().createHttpCommandResponse(
-                sendMessageResponseHeader,
-                SendMessageResponseBody
-                    .buildBody(EventMeshRetCode.EVENTMESH_PROTOCOL_BODY_ERR.getRetCode(),
-                        EventMeshRetCode.EVENTMESH_PROTOCOL_BODY_ERR.getErrMsg()));
+                    sendMessageResponseHeader,
+                    SendMessageResponseBody
+                            .buildBody(EventMeshRetCode.EVENTMESH_PROTOCOL_BODY_ERR.getRetCode(),
+                                    EventMeshRetCode.EVENTMESH_PROTOCOL_BODY_ERR.getErrMsg()));
             asyncContext.onComplete(responseEventMeshCommand);
             return;
         }
@@ -168,10 +168,10 @@ public class SendSyncMessageProcessor implements HttpRequestProcessor {
             } catch (Exception e) {
 
                 responseEventMeshCommand = asyncContext.getRequest().createHttpCommandResponse(
-                    sendMessageResponseHeader,
-                    SendMessageResponseBody
-                        .buildBody(EventMeshRetCode.EVENTMESH_ACL_ERR.getRetCode(),
-                            e.getMessage()));
+                        sendMessageResponseHeader,
+                        SendMessageResponseBody
+                                .buildBody(EventMeshRetCode.EVENTMESH_ACL_ERR.getRetCode(),
+                                        e.getMessage()));
                 asyncContext.onComplete(responseEventMeshCommand);
                 aclLogger.warn("CLIENT HAS NO PERMISSION,SendSyncMessageProcessor send failed", e);
                 return;
@@ -180,27 +180,40 @@ public class SendSyncMessageProcessor implements HttpRequestProcessor {
 
         // control flow rate limit
         if (!eventMeshHTTPServer.getMsgRateLimiter()
-            .tryAcquire(EventMeshConstants.DEFAULT_FASTFAIL_TIMEOUT_IN_MILLISECONDS,
-                TimeUnit.MILLISECONDS)) {
+                .tryAcquire(EventMeshConstants.DEFAULT_FASTFAIL_TIMEOUT_IN_MILLISECONDS,
+                        TimeUnit.MILLISECONDS)) {
             responseEventMeshCommand = asyncContext.getRequest().createHttpCommandResponse(
                 sendMessageResponseHeader,
                 SendMessageResponseBody
                     .buildBody(EventMeshRetCode.EVENTMESH_HTTP_MES_SEND_OVER_LIMIT_ERR.getRetCode(),
                         EventMeshRetCode.EVENTMESH_HTTP_MES_SEND_OVER_LIMIT_ERR.getErrMsg()));
-            eventMeshHTTPServer.metrics.summaryMetrics.recordHTTPDiscard();
+            eventMeshHTTPServer.metrics.getSummaryMetrics().recordHTTPDiscard();
+            asyncContext.onComplete(responseEventMeshCommand);
+            return;
+        }
+
+        String content = new String(event.getData().toBytes(), StandardCharsets.UTF_8);
+        if (content.length() > eventMeshHTTPServer.getEventMeshHttpConfiguration().eventMeshEventSize) {
+            httpLogger.error("Event size exceeds the limit: {}",
+                eventMeshHTTPServer.getEventMeshHttpConfiguration().eventMeshEventSize);
+
+            responseEventMeshCommand = asyncContext.getRequest().createHttpCommandResponse(
+                sendMessageResponseHeader,
+                SendMessageResponseBody.buildBody(EventMeshRetCode.EVENTMESH_PROTOCOL_BODY_ERR.getRetCode(),
+                    "Event size exceeds the limit: " + eventMeshHTTPServer.getEventMeshHttpConfiguration().eventMeshEventSize));
             asyncContext.onComplete(responseEventMeshCommand);
             return;
         }
 
         EventMeshProducer eventMeshProducer =
-            eventMeshHTTPServer.getProducerManager().getEventMeshProducer(producerGroup);
+                eventMeshHTTPServer.getProducerManager().getEventMeshProducer(producerGroup);
 
         if (!eventMeshProducer.getStarted().get()) {
             responseEventMeshCommand = asyncContext.getRequest().createHttpCommandResponse(
-                sendMessageResponseHeader,
-                SendMessageResponseBody
-                    .buildBody(EventMeshRetCode.EVENTMESH_GROUP_PRODUCER_STOPED_ERR.getRetCode(),
-                        EventMeshRetCode.EVENTMESH_GROUP_PRODUCER_STOPED_ERR.getErrMsg()));
+                    sendMessageResponseHeader,
+                    SendMessageResponseBody
+                            .buildBody(EventMeshRetCode.EVENTMESH_GROUP_PRODUCER_STOPED_ERR.getRetCode(),
+                                    EventMeshRetCode.EVENTMESH_GROUP_PRODUCER_STOPED_ERR.getErrMsg()));
             asyncContext.onComplete(responseEventMeshCommand);
             return;
         }
@@ -219,19 +232,19 @@ public class SendSyncMessageProcessor implements HttpRequestProcessor {
         } catch (Exception e) {
             messageLogger.error("msg2MQMsg err, bizSeqNo={}, topic={}", bizNo, topic, e);
             responseEventMeshCommand = asyncContext.getRequest().createHttpCommandResponse(
-                sendMessageResponseHeader,
-                SendMessageResponseBody
-                    .buildBody(EventMeshRetCode.EVENTMESH_PACKAGE_MSG_ERR.getRetCode(),
-                        EventMeshRetCode.EVENTMESH_PACKAGE_MSG_ERR.getErrMsg()
-                            + EventMeshUtil.stackTrace(e, 2)));
+                    sendMessageResponseHeader,
+                    SendMessageResponseBody
+                            .buildBody(EventMeshRetCode.EVENTMESH_PACKAGE_MSG_ERR.getRetCode(),
+                                    EventMeshRetCode.EVENTMESH_PACKAGE_MSG_ERR.getErrMsg()
+                                            + EventMeshUtil.stackTrace(e, 2)));
             asyncContext.onComplete(responseEventMeshCommand);
             return;
         }
 
         final SendMessageContext sendMessageContext =
-            new SendMessageContext(bizNo, event, eventMeshProducer,
-                eventMeshHTTPServer);
-        eventMeshHTTPServer.metrics.summaryMetrics.recordSendMsg();
+                new SendMessageContext(bizNo, event, eventMeshProducer,
+                        eventMeshHTTPServer);
+        eventMeshHTTPServer.metrics.getSummaryMetrics().recordSendMsg();
 
         long startTime = System.currentTimeMillis();
 
@@ -243,7 +256,7 @@ public class SendSyncMessageProcessor implements HttpRequestProcessor {
                         httpLogger.debug("{}", httpCommand);
                     }
                     eventMeshHTTPServer.sendResponse(ctx, httpCommand.httpResponse());
-                    eventMeshHTTPServer.metrics.summaryMetrics.recordHTTPReqResTimeCost(
+                    eventMeshHTTPServer.metrics.getSummaryMetrics().recordHTTPReqResTimeCost(
                         System.currentTimeMillis() - asyncContext.getRequest().getReqTime());
                 } catch (Exception ex) {
                     // ignore
@@ -257,35 +270,35 @@ public class SendSyncMessageProcessor implements HttpRequestProcessor {
                 @Override
                 public void onSuccess(CloudEvent event) {
                     messageLogger.info("message|mq2eventMesh|RSP|SYNC|rrCost={}ms|topic={}"
-                            + "|bizSeqNo={}|uniqueId={}", System.currentTimeMillis() - startTime,
-                        topic, bizNo, uniqueId);
+                                    + "|bizSeqNo={}|uniqueId={}", System.currentTimeMillis() - startTime,
+                            topic, bizNo, uniqueId);
 
                     try {
                         event = CloudEventBuilder.from(event)
                                 .withExtension(EventMeshConstants.RSP_EVENTMESH2C_TIMESTAMP,
-                                String.valueOf(System.currentTimeMillis()))
-                            .withExtension(EventMeshConstants.RSP_MQ2EVENTMESH_TIMESTAMP,
-                                String.valueOf(System.currentTimeMillis()))
-                            .build();
+                                        String.valueOf(System.currentTimeMillis()))
+                                .withExtension(EventMeshConstants.RSP_MQ2EVENTMESH_TIMESTAMP,
+                                        String.valueOf(System.currentTimeMillis()))
+                                .build();
                         final String rtnMsg = new String(event.getData().toBytes(),
-                            EventMeshConstants.DEFAULT_CHARSET);
+                                EventMeshConstants.DEFAULT_CHARSET);
 
                         HttpCommand succ = asyncContext.getRequest().createHttpCommandResponse(
-                            sendMessageResponseHeader,
-                            SendMessageResponseBody.buildBody(EventMeshRetCode.SUCCESS.getRetCode(),
-                                JsonUtils.serialize(SendMessageResponseBody.ReplyMessage.builder()
-                                    .topic(topic)
-                                    .body(rtnMsg)
-                                    .properties(EventMeshUtil.getEventProp(event))
-                                    .build())));
+                                sendMessageResponseHeader,
+                                SendMessageResponseBody.buildBody(EventMeshRetCode.SUCCESS.getRetCode(),
+                                        JsonUtils.serialize(SendMessageResponseBody.ReplyMessage.builder()
+                                                .topic(topic)
+                                                .body(rtnMsg)
+                                                .properties(EventMeshUtil.getEventProp(event))
+                                                .build())));
                         asyncContext.onComplete(succ, handler);
                     } catch (Exception ex) {
                         HttpCommand err = asyncContext.getRequest().createHttpCommandResponse(
-                            sendMessageResponseHeader,
-                            SendMessageResponseBody.buildBody(
-                                EventMeshRetCode.EVENTMESH_WAITING_RR_MSG_ERR.getRetCode(),
-                                EventMeshRetCode.EVENTMESH_WAITING_RR_MSG_ERR.getErrMsg()
-                                    + EventMeshUtil.stackTrace(ex, 2)));
+                                sendMessageResponseHeader,
+                                SendMessageResponseBody.buildBody(
+                                        EventMeshRetCode.EVENTMESH_WAITING_RR_MSG_ERR.getRetCode(),
+                                        EventMeshRetCode.EVENTMESH_WAITING_RR_MSG_ERR.getErrMsg()
+                                                + EventMeshUtil.stackTrace(ex, 2)));
                         asyncContext.onComplete(err, handler);
                         messageLogger.warn("message|mq2eventMesh|RSP", ex);
                     }
@@ -294,18 +307,18 @@ public class SendSyncMessageProcessor implements HttpRequestProcessor {
                 @Override
                 public void onException(Throwable e) {
                     HttpCommand err = asyncContext.getRequest().createHttpCommandResponse(
-                        sendMessageResponseHeader,
-                        SendMessageResponseBody
-                            .buildBody(EventMeshRetCode.EVENTMESH_WAITING_RR_MSG_ERR.getRetCode(),
-                                EventMeshRetCode.EVENTMESH_WAITING_RR_MSG_ERR.getErrMsg()
-                                    + EventMeshUtil.stackTrace(e, 2)));
+                            sendMessageResponseHeader,
+                            SendMessageResponseBody
+                                    .buildBody(EventMeshRetCode.EVENTMESH_WAITING_RR_MSG_ERR.getRetCode(),
+                                            EventMeshRetCode.EVENTMESH_WAITING_RR_MSG_ERR.getErrMsg()
+                                                    + EventMeshUtil.stackTrace(e, 2)));
                     asyncContext.onComplete(err, handler);
 
                     eventMeshHTTPServer.getHttpRetryer().pushRetry(sendMessageContext.delay(10000));
                     messageLogger.error(
-                        "message|mq2eventMesh|RSP|SYNC|rrCost={}ms|topic={}"
-                            + "|bizSeqNo={}|uniqueId={}", System.currentTimeMillis() - startTime,
-                        topic, bizNo, uniqueId, e);
+                            "message|mq2eventMesh|RSP|SYNC|rrCost={}ms|topic={}"
+                                    + "|bizSeqNo={}|uniqueId={}", System.currentTimeMillis() - startTime,
+                            topic, bizNo, uniqueId, e);
                 }
             }, Integer.parseInt(ttl));
         } catch (Exception ex) {
@@ -319,8 +332,8 @@ public class SendSyncMessageProcessor implements HttpRequestProcessor {
 
             eventMeshHTTPServer.getHttpRetryer().pushRetry(sendMessageContext.delay(10000));
             long endTime = System.currentTimeMillis();
-            eventMeshHTTPServer.metrics.summaryMetrics.recordSendMsgFailed();
-            eventMeshHTTPServer.metrics.summaryMetrics.recordSendMsgCost(endTime - startTime);
+            eventMeshHTTPServer.metrics.getSummaryMetrics().recordSendMsgFailed();
+            eventMeshHTTPServer.metrics.getSummaryMetrics().recordSendMsgCost(endTime - startTime);
             messageLogger.error(
                 "message|eventMesh2mq|REQ|SYNC|send2MQCost={}ms|topic={}|bizSeqNo={}|uniqueId={}",
                 endTime - startTime, topic, bizNo, uniqueId, ex);
