@@ -19,22 +19,12 @@ package org.apache.eventmesh.runtime.core.protocol.tcp.client.session;
 
 import static org.apache.eventmesh.common.protocol.tcp.Command.LISTEN_RESPONSE;
 
-import java.lang.ref.WeakReference;
-import java.net.InetSocketAddress;
-import java.util.List;
-import java.util.concurrent.locks.ReentrantLock;
-
-import io.cloudevents.CloudEvent;
-import io.netty.channel.ChannelFuture;
-import io.netty.channel.ChannelFutureListener;
-import io.netty.channel.ChannelHandlerContext;
-
-import org.apache.commons.lang3.time.DateFormatUtils;
 import org.apache.eventmesh.api.SendCallback;
-import org.apache.eventmesh.common.Constants;
 import org.apache.eventmesh.common.protocol.SubscriptionItem;
-import org.apache.eventmesh.common.protocol.tcp.*;
+import org.apache.eventmesh.common.protocol.tcp.Header;
+import org.apache.eventmesh.common.protocol.tcp.OPStatus;
 import org.apache.eventmesh.common.protocol.tcp.Package;
+import org.apache.eventmesh.common.protocol.tcp.UserAgent;
 import org.apache.eventmesh.runtime.configuration.EventMeshTCPConfiguration;
 import org.apache.eventmesh.runtime.constants.EventMeshConstants;
 import org.apache.eventmesh.runtime.core.protocol.tcp.client.group.ClientGroupWrapper;
@@ -44,9 +34,22 @@ import org.apache.eventmesh.runtime.core.protocol.tcp.client.session.send.EventM
 import org.apache.eventmesh.runtime.core.protocol.tcp.client.session.send.SessionSender;
 import org.apache.eventmesh.runtime.util.RemotingHelper;
 import org.apache.eventmesh.runtime.util.Utils;
+
+import org.apache.commons.lang3.time.DateFormatUtils;
+
+import java.lang.ref.WeakReference;
+import java.net.InetSocketAddress;
+import java.util.List;
+import java.util.concurrent.locks.ReentrantLock;
+
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import io.cloudevents.CloudEvent;
+import io.netty.channel.ChannelFuture;
+import io.netty.channel.ChannelFutureListener;
+import io.netty.channel.ChannelHandlerContext;
+
 public class Session {
 
     protected final Logger messageLogger = LoggerFactory.getLogger("message");
@@ -168,7 +171,7 @@ public class Session {
 
             clientGroupWrapper.get().getMqProducerWrapper().getMeshMQProducer().checkTopicExist(item.getTopic());
 
-            clientGroupWrapper.get().addSubscription(item.getTopic(), this);
+            clientGroupWrapper.get().addSubscription(item, this);
             subscribeLogger.info("subscribe|succeed|topic={}|user={}", item.getTopic(), client);
         }
     }
@@ -176,7 +179,7 @@ public class Session {
     public void unsubscribe(List<SubscriptionItem> items) throws Exception {
         for (SubscriptionItem item : items) {
             sessionContext.subscribeTopics.remove(item.getTopic());
-            clientGroupWrapper.get().removeSubscription(item.getTopic(), this);
+            clientGroupWrapper.get().removeSubscription(item, this);
 
             if (!clientGroupWrapper.get().hasSubscription(item.getTopic())) {
                 clientGroupWrapper.get().unsubscribe(item);
@@ -215,7 +218,8 @@ public class Session {
                             if (!future.isSuccess()) {
                                 messageLogger.error("write2Client fail, pkg[{}] session[{}]", pkg, this);
                             } else {
-                                clientGroupWrapper.get().getEventMeshTcpMonitor().getEventMesh2clientMsgNum().incrementAndGet();
+                                clientGroupWrapper.get().getEventMeshTcpMonitor().getTcpSummaryMetrics().getEventMesh2clientMsgNum()
+                                    .incrementAndGet();
                             }
                         }
                     }
@@ -227,15 +231,24 @@ public class Session {
 
     @Override
     public String toString() {
-        return "Session{" +
-                "sysId=" + clientGroupWrapper.get().getSysId() +
-                ",remoteAddr=" + RemotingHelper.parseSocketAddressAddr(remoteAddress) +
-                ",client=" + client +
-                ",sessionState=" + sessionState +
-                ",sessionContext=" + sessionContext +
-                ",pusher=" + pusher +
-                ",sender=" + sender +
-                ",createTime=" + DateFormatUtils.format(createTime, EventMeshConstants.DATE_FORMAT) +
+        return "Session{"
+                +
+                "sysId=" + clientGroupWrapper.get().getSysId()
+                +
+                ",remoteAddr=" + RemotingHelper.parseSocketAddressAddr(remoteAddress)
+                +
+                ",client=" + client
+                +
+                ",sessionState=" + sessionState
+                +
+                ",sessionContext=" + sessionContext
+                +
+                ",pusher=" + pusher
+                +
+                ",sender=" + sender
+                +
+                ",createTime=" + DateFormatUtils.format(createTime, EventMeshConstants.DATE_FORMAT)
+                +
                 ",lastHeartbeatTime=" + DateFormatUtils.format(lastHeartbeatTime, EventMeshConstants.DATE_FORMAT) + '}';
     }
 
@@ -319,17 +332,17 @@ public class Session {
         }
 
         if (!sessionContext.subscribeTopics.containsKey(topic)) {
-            logger.warn("session is not available because session has not subscribe topic:{},client:{}", topic,client);
+            logger.warn("session is not available because session has not subscribe topic:{},client:{}", topic, client);
             return false;
         }
 
         return true;
     }
 
-//    @Override
-//    public int hashCode() {
-//        int code = 37 + (client != null ? client.hashCode() : 0) + (context != null ? context.hashCode() : 0)
-//                + (sessionState != null ? sessionState.hashCode() : 0);
-//        return code;
-//    }
+    //@Override
+    //public int hashCode() {
+    //    int code = 37 + (client != null ? client.hashCode() : 0) + (context != null ? context.hashCode() : 0)
+    //            + (sessionState != null ? sessionState.hashCode() : 0);
+    //    return code;
+    //}
 }
