@@ -17,11 +17,7 @@
 
 package org.apache.eventmesh.runtime.core.protocol.tcp.client.session.push;
 
-import io.cloudevents.CloudEvent;
-import org.apache.commons.lang3.StringUtils;
-import org.apache.commons.lang3.time.DateFormatUtils;
 import org.apache.eventmesh.api.AbstractContext;
-import org.apache.eventmesh.common.Constants;
 import org.apache.eventmesh.common.protocol.SubscriptionItem;
 import org.apache.eventmesh.common.protocol.SubscriptionMode;
 import org.apache.eventmesh.runtime.constants.EventMeshConstants;
@@ -30,11 +26,18 @@ import org.apache.eventmesh.runtime.core.protocol.tcp.client.session.Session;
 import org.apache.eventmesh.runtime.core.protocol.tcp.client.session.retry.RetryContext;
 import org.apache.eventmesh.runtime.util.EventMeshUtil;
 import org.apache.eventmesh.runtime.util.ServerGlobal;
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
+
+import org.apache.commons.lang3.StringUtils;
+import org.apache.commons.lang3.time.DateFormatUtils;
+
 import java.util.ArrayList;
 import java.util.List;
 
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+
+import io.cloudevents.CloudEvent;
+
 public class DownStreamMsgContext extends RetryContext {
 
     private final Logger logger = LoggerFactory.getLogger(this.getClass());
@@ -55,7 +58,9 @@ public class DownStreamMsgContext extends RetryContext {
 
     public boolean msgFromOtherEventMesh;
 
-    public DownStreamMsgContext(CloudEvent event, Session session, MQConsumerWrapper consumer, AbstractContext consumeConcurrentlyContext, boolean msgFromOtherEventMesh, SubscriptionItem subscriptionItem) {
+    public DownStreamMsgContext(CloudEvent event, Session session, MQConsumerWrapper consumer,
+                                AbstractContext consumeConcurrentlyContext, boolean msgFromOtherEventMesh,
+                                SubscriptionItem subscriptionItem) {
         this.seq = String.valueOf(ServerGlobal.getInstance().getMsgCounter().incrementAndGet());
         this.event = event;
         this.session = session;
@@ -65,8 +70,9 @@ public class DownStreamMsgContext extends RetryContext {
         this.createTime = System.currentTimeMillis();
         this.subscriptionItem = subscriptionItem;
         String ttlStr = (String) event.getExtension("TTL");
-//        String ttlStr = msgExt.getUserProperties("TTL");
-        long ttl = StringUtils.isNumeric(ttlStr) ? Long.parseLong(ttlStr) : EventMeshConstants.DEFAULT_TIMEOUT_IN_MILLISECONDS;
+        //String ttlStr = msgExt.getUserProperties("TTL");
+        long ttl = StringUtils.isNumeric(ttlStr) ? Long.parseLong(ttlStr) :
+                EventMeshConstants.DEFAULT_TIMEOUT_IN_MILLISECONDS;
         this.expireTime = System.currentTimeMillis() + ttl;
         this.msgFromOtherEventMesh = msgFromOtherEventMesh;
     }
@@ -80,34 +86,47 @@ public class DownStreamMsgContext extends RetryContext {
             List<CloudEvent> events = new ArrayList<CloudEvent>();
             events.add(event);
             consumer.updateOffset(events, consumeConcurrentlyContext);
-//            ConsumeMessageService consumeMessageService = consumer.getDefaultMQPushConsumer().getDefaultMQPushConsumerImpl().getConsumeMessageService();
-//            ((ConsumeMessageConcurrentlyService)consumeMessageService).updateOffset(msgs, consumeConcurrentlyContext);
+            //ConsumeMessageService consumeMessageService =
+            // consumer.getDefaultMQPushConsumer().getDefaultMQPushConsumerImpl().getConsumeMessageService();
+            //((ConsumeMessageConcurrentlyService)consumeMessageService).updateOffset(msgs, consumeConcurrentlyContext);
             logger.info("ackMsg seq:{}, topic:{}, bizSeq:{}", seq, events.get(0).getSubject(),
                     events.get(0).getExtension(EventMeshConstants.PROPERTY_MESSAGE_KEYS));
         } else {
-            logger.warn("ackMsg seq:{} failed,consumer is null:{}, context is null:{} , msgs is null:{}", seq, consumer == null, consumeConcurrentlyContext == null, event == null);
+            logger.warn("ackMsg seq:{} failed,consumer is null:{}, context is null:{} , msgs is null:{}", seq,
+                    consumer == null, consumeConcurrentlyContext == null, event == null);
         }
     }
 
     @Override
     public String toString() {
-        return "DownStreamMsgContext{" +
-                ",seq=" + seq +
-                ",client=" + (session == null ? null : session.getClient()) +
-                ",retryTimes=" + retryTimes +
-                ",consumer=" + consumer +
-//  todo              ",consumerGroup=" + consumer.getClass().getConsumerGroup() +
-                ",topic=" + event.getSubject() +
-                ",subscriptionItem=" + subscriptionItem +
-                ",createTime=" + DateFormatUtils.format(createTime, EventMeshConstants.DATE_FORMAT) +
-                ",executeTime=" + DateFormatUtils.format(executeTime, EventMeshConstants.DATE_FORMAT) +
-                ",lastPushTime=" + DateFormatUtils.format(lastPushTime, EventMeshConstants.DATE_FORMAT) + '}';
+        return "DownStreamMsgContext{"
+                +
+                ",seq=" + seq
+                +
+                ",client=" + (session == null ? null : session.getClient())
+                +
+                ",retryTimes=" + retryTimes
+                +
+                ",consumer=" + consumer
+                +
+                //  todo              ",consumerGroup=" + consumer.getClass().getConsumerGroup() +
+                ",topic=" + event.getSubject()
+                +
+                ",subscriptionItem=" + subscriptionItem
+                +
+                ",createTime=" + DateFormatUtils.format(createTime, EventMeshConstants.DATE_FORMAT)
+                +
+                ",executeTime=" + DateFormatUtils.format(executeTime, EventMeshConstants.DATE_FORMAT)
+                +
+                ",lastPushTime=" + DateFormatUtils.format(lastPushTime, EventMeshConstants.DATE_FORMAT)
+                + '}';
     }
 
     @Override
     public void retry() {
         try {
-            logger.info("retry downStream msg start,seq:{},retryTimes:{},bizSeq:{}", this.seq, this.retryTimes, EventMeshUtil.getMessageBizSeq(this.event));
+            logger.info("retry downStream msg start,seq:{},retryTimes:{},bizSeq:{}", this.seq, this.retryTimes,
+                    EventMeshUtil.getMessageBizSeq(this.event));
 
             if (isRetryMsgTimeout(this)) {
                 return;
@@ -119,18 +138,20 @@ public class DownStreamMsgContext extends RetryContext {
             String topic = this.event.getSubject();
             if (!SubscriptionMode.BROADCASTING.equals(this.subscriptionItem.getMode())) {
                 rechoosen = this.session.getClientGroupWrapper()
-                        .get().getDownstreamDispatchStrategy().select(this.session.getClientGroupWrapper().get().getSysId()
-                                , topic, this.session.getClientGroupWrapper().get().getGroupConsumerSessions());
+                        .get().getDownstreamDispatchStrategy().select(this.session.getClientGroupWrapper().get().getSysId(),
+                                topic, this.session.getClientGroupWrapper().get().getGroupConsumerSessions());
             } else {
                 rechoosen = this.session;
             }
 
             if (rechoosen == null) {
-                logger.warn("retry, found no session to downstream msg,seq:{}, retryTimes:{}, bizSeq:{}", this.seq, this.retryTimes, EventMeshUtil.getMessageBizSeq(this.event));
+                logger.warn("retry, found no session to downstream msg,seq:{}, retryTimes:{}, bizSeq:{}", this.seq,
+                        this.retryTimes, EventMeshUtil.getMessageBizSeq(this.event));
             } else {
                 this.session = rechoosen;
                 rechoosen.downstreamMsg(this);
-                logger.info("retry downStream msg end,seq:{},retryTimes:{},bizSeq:{}", this.seq, this.retryTimes, EventMeshUtil.getMessageBizSeq(this.event));
+                logger.info("retry downStream msg end,seq:{},retryTimes:{},bizSeq:{}", this.seq, this.retryTimes,
+                        EventMeshUtil.getMessageBizSeq(this.event));
             }
         } catch (Exception e) {
             logger.error("retry-dispatcher error!", e);
@@ -140,7 +161,8 @@ public class DownStreamMsgContext extends RetryContext {
     private boolean isRetryMsgTimeout(DownStreamMsgContext downStreamMsgContext) {
         boolean flag = false;
         String ttlStr = (String) downStreamMsgContext.event.getExtension(EventMeshConstants.PROPERTY_MESSAGE_TTL);
-        long ttl = StringUtils.isNumeric(ttlStr) ? Long.parseLong(ttlStr) : EventMeshConstants.DEFAULT_TIMEOUT_IN_MILLISECONDS;;
+        long ttl = StringUtils.isNumeric(ttlStr) ? Long.parseLong(ttlStr) : EventMeshConstants.DEFAULT_TIMEOUT_IN_MILLISECONDS;
+        ;
 
         String storeTimeStr = (String) downStreamMsgContext.event.getExtension(EventMeshConstants.STORE_TIME);
         long storeTimestamp = StringUtils.isNumeric(storeTimeStr) ? Long.parseLong(storeTimeStr) : 0;
@@ -148,10 +170,13 @@ public class DownStreamMsgContext extends RetryContext {
         long brokerCost = StringUtils.isNumeric(leaveTimeStr) ? Long.parseLong(leaveTimeStr) - storeTimestamp : 0;
 
         String arriveTimeStr = (String) downStreamMsgContext.event.getExtension(EventMeshConstants.ARRIVE_TIME);
-        long accessCost = StringUtils.isNumeric(arriveTimeStr) ? System.currentTimeMillis() - Long.parseLong(arriveTimeStr) : 0;
+        long accessCost = StringUtils.isNumeric(arriveTimeStr) ? System.currentTimeMillis() - Long.parseLong(arriveTimeStr)
+                : 0;
+
         double elapseTime = brokerCost + accessCost;
         if (elapseTime >= ttl) {
-            logger.warn("discard the retry because timeout, seq:{}, retryTimes:{}, bizSeq:{}", downStreamMsgContext.seq, downStreamMsgContext.retryTimes, EventMeshUtil.getMessageBizSeq(downStreamMsgContext.event));
+            logger.warn("discard the retry because timeout, seq:{}, retryTimes:{}, bizSeq:{}", downStreamMsgContext.seq,
+                    downStreamMsgContext.retryTimes, EventMeshUtil.getMessageBizSeq(downStreamMsgContext.event));
             flag = true;
             eventMeshAckMsg(downStreamMsgContext);
         }
