@@ -17,9 +17,6 @@
 
 package org.apache.eventmesh.runtime.core.protocol.tcp.client.session.send;
 
-import io.cloudevents.core.builder.CloudEventBuilder;
-import org.apache.commons.lang3.StringUtils;
-import org.apache.commons.lang3.time.DateFormatUtils;
 import org.apache.eventmesh.api.RequestReplyCallback;
 import org.apache.eventmesh.api.SendCallback;
 import org.apache.eventmesh.common.Constants;
@@ -31,17 +28,21 @@ import org.apache.eventmesh.protocol.api.ProtocolAdaptor;
 import org.apache.eventmesh.protocol.api.ProtocolPluginFactory;
 import org.apache.eventmesh.runtime.constants.EventMeshConstants;
 import org.apache.eventmesh.runtime.core.protocol.tcp.client.session.Session;
-import org.apache.eventmesh.runtime.util.EventMeshUtil;
 import org.apache.eventmesh.runtime.util.Utils;
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
+
+import org.apache.commons.lang3.StringUtils;
+import org.apache.commons.lang3.time.DateFormatUtils;
 
 import java.util.Objects;
 import java.util.concurrent.Semaphore;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicLong;
 
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+
 import io.cloudevents.CloudEvent;
+import io.cloudevents.core.builder.CloudEventBuilder;
 
 public class SessionSender {
 
@@ -60,9 +61,12 @@ public class SessionSender {
 
     @Override
     public String toString() {
-        return "SessionSender{upstreamBuff=" + upstreamBuff.availablePermits() +
-                ",upMsgs=" + upMsgs.longValue() +
-                ",failMsgCount=" + failMsgCount.longValue() +
+        return "SessionSender{upstreamBuff=" + upstreamBuff.availablePermits()
+                +
+                ",upMsgs=" + upMsgs.longValue()
+                +
+                ",failMsgCount=" + failMsgCount.longValue()
+                +
                 ",createTime=" + DateFormatUtils.format(createTime, EventMeshConstants.DATE_FORMAT) + '}';
     }
 
@@ -86,27 +90,33 @@ public class SessionSender {
                 long ttl = EventMeshConstants.DEFAULT_TIMEOUT_IN_MILLISECONDS;
                 if (Command.REQUEST_TO_SERVER == cmd) {
                     if (event.getExtension(EventMeshConstants.PROPERTY_MESSAGE_TTL) != null) {
-                       ttl = Long.parseLong((String) Objects.requireNonNull(event.getExtension(EventMeshConstants.PROPERTY_MESSAGE_TTL)));
+                        ttl = Long.parseLong((String) Objects.requireNonNull(
+                                event.getExtension(EventMeshConstants.PROPERTY_MESSAGE_TTL)));
                     }
-//                    long ttl = msg.getSystemProperties(EventMeshConstants.PROPERTY_MESSAGE_TTL) != null ? Long.parseLong(msg.getSystemProperties(EventMeshConstants.PROPERTY_MESSAGE_TTL)) : EventMeshConstants.DEFAULT_TIMEOUT_IN_MILLISECONDS;
+                    //long ttl = msg.getSystemProperties(EventMeshConstants.PROPERTY_MESSAGE_TTL) != null ?
+                    // Long.parseLong(msg.getSystemProperties(EventMeshConstants.PROPERTY_MESSAGE_TTL))
+                    // : EventMeshConstants.DEFAULT_TIMEOUT_IN_MILLISECONDS;
                     upStreamMsgContext = new UpStreamMsgContext(session, event, header, startTime, taskExecuteTime);
-                    session.getClientGroupWrapper().get().request(upStreamMsgContext, initSyncRRCallback(header, startTime, taskExecuteTime), ttl);
+                    session.getClientGroupWrapper().get().request(upStreamMsgContext, initSyncRRCallback(header,
+                            startTime, taskExecuteTime), ttl);
                     upstreamBuff.release();
                 } else if (Command.RESPONSE_TO_SERVER == cmd) {
-                    String cluster = (String)event.getExtension(EventMeshConstants.PROPERTY_MESSAGE_CLUSTER);
-//                    String cluster = msg.getUserProperties(EventMeshConstants.PROPERTY_MESSAGE_CLUSTER);
+                    String cluster = (String) event.getExtension(EventMeshConstants.PROPERTY_MESSAGE_CLUSTER);
+                    //String cluster = msg.getUserProperties(EventMeshConstants.PROPERTY_MESSAGE_CLUSTER);
                     if (!StringUtils.isEmpty(cluster)) {
                         String replyTopic = EventMeshConstants.RR_REPLY_TOPIC;
                         replyTopic = cluster + "-" + replyTopic;
                         event = CloudEventBuilder.from(event).withSubject(replyTopic).build();
-//                        msg.getSystemProperties().put(Constants.PROPERTY_MESSAGE_DESTINATION, replyTopic);
-//                        event(replyTopic);
+                        //msg.getSystemProperties().put(Constants.PROPERTY_MESSAGE_DESTINATION, replyTopic);
+                        //event(replyTopic);
                     }
 
-//                    //for rocketmq support
-//                    MessageAccessor.putProperty(msg, MessageConst.PROPERTY_MESSAGE_TYPE, MixAll.REPLY_MESSAGE_FLAG);
-//                    MessageAccessor.putProperty(msg, MessageConst.PROPERTY_CORRELATION_ID, msg.getProperty(DeFiBusConstant.PROPERTY_RR_REQUEST_ID));
-//                    MessageAccessor.putProperty(msg, MessageConst.PROPERTY_MESSAGE_REPLY_TO_CLIENT, msg.getProperty(DeFiBusConstant.PROPERTY_MESSAGE_REPLY_TO));
+                    ////for rocketmq support
+                    //MessageAccessor.putProperty(msg, MessageConst.PROPERTY_MESSAGE_TYPE, MixAll.REPLY_MESSAGE_FLAG);
+                    //MessageAccessor.putProperty(msg, MessageConst.PROPERTY_CORRELATION_ID,
+                    // msg.getProperty(DeFiBusConstant.PROPERTY_RR_REQUEST_ID));
+                    //MessageAccessor.putProperty(msg, MessageConst.PROPERTY_MESSAGE_REPLY_TO_CLIENT,
+                    // msg.getProperty(DeFiBusConstant.PROPERTY_MESSAGE_REPLY_TO));
 
                     upStreamMsgContext = new UpStreamMsgContext(session, event, header, startTime, taskExecuteTime);
                     session.getClientGroupWrapper().get().reply(upStreamMsgContext);
@@ -116,7 +126,7 @@ public class SessionSender {
                     session.getClientGroupWrapper().get().send(upStreamMsgContext, sendCallback);
                 }
 
-                session.getClientGroupWrapper().get().getEventMeshTcpMonitor().getEventMesh2mqMsgNum().incrementAndGet();
+                session.getClientGroupWrapper().get().getEventMeshTcpMonitor().getTcpSummaryMetrics().getEventMesh2mqMsgNum().incrementAndGet();
             } else {
                 logger.warn("send too fast,session flow control,session:{}", session.getClient());
                 return new EventMeshTcpSendResult(header.getSeq(), EventMeshTcpSendStatus.SEND_TOO_FAST, EventMeshTcpSendStatus.SEND_TOO_FAST.name());
@@ -138,17 +148,17 @@ public class SessionSender {
             public void onSuccess(CloudEvent event) {
                 String seq = header.getSeq();
                 // TODO: How to assign values here
-//                if (msg instanceof MessageExt) {
-//                    msg.putUserProperty(EventMeshConstants.BORN_TIMESTAMP, String.valueOf(((MessageExt) msg)
-//                            .getBornTimestamp()));
-//                    msg.putUserProperty(EventMeshConstants.STORE_TIMESTAMP, String.valueOf(((MessageExt) msg)
-//                            .getStoreTimestamp()));
-//                }
+                //if (msg instanceof MessageExt) {
+                //    msg.putUserProperty(EventMeshConstants.BORN_TIMESTAMP, String.valueOf(((MessageExt) msg)
+                //            .getBornTimestamp()));
+                //    msg.putUserProperty(EventMeshConstants.STORE_TIMESTAMP, String.valueOf(((MessageExt) msg)
+                //            .getStoreTimestamp()));
+                //}
                 event = CloudEventBuilder.from(event)
                         .withExtension(EventMeshConstants.RSP_MQ2EVENTMESH_TIMESTAMP, String.valueOf(System.currentTimeMillis()))
                         .withExtension(EventMeshConstants.RSP_RECEIVE_EVENTMESH_IP, session.getEventMeshTCPConfiguration().eventMeshServerIp)
                         .build();
-                session.getClientGroupWrapper().get().getEventMeshTcpMonitor().getMq2EventMeshMsgNum().incrementAndGet();
+                session.getClientGroupWrapper().get().getEventMeshTcpMonitor().getTcpSummaryMetrics().getMq2eventMeshMsgNum().incrementAndGet();
 
                 Command cmd;
                 if (header.getCmd().equals(Command.REQUEST_TO_SERVER)) {
@@ -158,17 +168,17 @@ public class SessionSender {
                     return;
                 }
                 event = CloudEventBuilder.from(event)
-                    .withExtension(EventMeshConstants.RSP_EVENTMESH2C_TIMESTAMP, String.valueOf(System.currentTimeMillis()))
-                    .build();
+                        .withExtension(EventMeshConstants.RSP_EVENTMESH2C_TIMESTAMP, String.valueOf(System.currentTimeMillis()))
+                        .build();
                 String protocolType = Objects.requireNonNull(event.getExtension(Constants.PROTOCOL_TYPE)).toString();
 
                 ProtocolAdaptor protocolAdaptor = ProtocolPluginFactory.getProtocolAdaptor(protocolType);
 
                 Package pkg = new Package();
 
-//                msg.getSystemProperties().put(EventMeshConstants.RSP_EVENTMESH2C_TIMESTAMP, String.valueOf(System.currentTimeMillis()));
+                //msg.getSystemProperties().put(EventMeshConstants.RSP_EVENTMESH2C_TIMESTAMP, String.valueOf(System.currentTimeMillis()));
                 try {
-//                    pkg.setBody(EventMeshUtil.encodeMessage(msg));
+                    //pkg.setBody(EventMeshUtil.encodeMessage(msg));
                     pkg = (Package) protocolAdaptor.fromCloudEvent(event);
                     pkg.setHeader(new Header(cmd, OPStatus.SUCCESS.getCode(), null, seq));
                     pkg.getHeader().putProperty(Constants.PROTOCOL_TYPE, protocolType);
